aboutsummaryrefslogtreecommitdiffstats
path: root/targphys.h
diff options
context:
space:
mode:
Diffstat (limited to 'targphys.h')
-rw-r--r--targphys.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/targphys.h b/targphys.h
index 2a5b1bd54..99ab23c7a 100644
--- a/targphys.h
+++ b/targphys.h
@@ -1,21 +1,21 @@
/* Define a_target_phys_addr if it exists. */
#ifndef TARGPHYS_H
#define TARGPHYS_H
#ifdef TARGET_PHYS_ADDR_BITS
/* a_target_phys_addr is the type of a physical address (its size can
be different from 'target_ulong'). We have sizeof(target_phys_addr)
= max(sizeof(unsigned long),
sizeof(size_of_target_physical_address)) because we must pass a
host pointer to memory operations in some cases */
#if TARGET_PHYS_ADDR_BITS == 32
-typedef uint32_t a_target_phys_addr;
+typedef uint32_t target_phys_addr_t;
#define TARGET_PHYS_ADDR_MAX UINT32_MAX
#define TARGET_FMT_plx "%08x"
#elif TARGET_PHYS_ADDR_BITS == 64
-typedef uint64_t a_target_phys_addr;
+typedef uint64_t target_phys_addr_t;
#define TARGET_PHYS_ADDR_MAX UINT64_MAX
#define TARGET_FMT_plx "%016" PRIx64
#endif
@@ -1,21 +1,21 @@
-/* Define a_target_phys_addr if it exists. */
+/* Define target_phys_addr_t if it exists. */
#ifndef TARGPHYS_H
#define TARGPHYS_H
@@ -1,21 +1,21 @@
#define TARGPHYS_H
#ifdef TARGET_PHYS_ADDR_BITS
-/* a_target_phys_addr is the type of a physical address (its size can
+/* target_phys_addr_t is the type of a physical address (its size can
be different from 'target_ulong'). We have sizeof(target_phys_addr)
= max(sizeof(unsigned long),